# -*- coding: utf-8 -*-

"""Exercise Add/Edit dialog class"""

import wx
import wx.xrc as xrc
import os
from wx.animate import GIFAnimationCtrl
from Hercules.gui.exercisewizard import ExerciseWizard
from Hercules.globals import imagesDir


class ExerciseDlg:
    """Exercise dialog"""

    def __init__(self, parent, resource):
        self.dlg = resource.LoadDialog(parent, 'ExerciseDialog')

        # Configure OK & Cancel buttons for default behavior.
        self.dlg.FindWindowByName('wxID_OK'    ).SetId(wx.ID_OK)
        self.dlg.FindWindowByName('wxID_CANCEL').SetId(wx.ID_CANCEL)

        # Init the all other widgets
        self.titleBox = xrc.XRCCTRL(self.dlg, 'titleBox')
        self.utilityBox = xrc.XRCCTRL(self.dlg, 'utilityBox')
        self.mechanicsBox = xrc.XRCCTRL(self.dlg, 'mechanicsBox')
        self.forceBox = xrc.XRCCTRL(self.dlg, 'forceBox')
        self.instructionsText = xrc.XRCCTRL(self.dlg, 'instructionsText')
        self.musclesText = xrc.XRCCTRL(self.dlg, 'musclesText')
        self.commentsText = xrc.XRCCTRL(self.dlg, 'commentsText')
        self.imageBox = xrc.XRCCTRL(self.dlg, 'imageBox')

        # Bind event handler
        self.dlg.Bind(wx.EVT_BUTTON, self.OnGetFromWEB,
                        id=xrc.XRCID("wizardBtn"))

        self.exerciseInfo = ['', '', '', '', '', '', '', '']

    def OnGetFromWEB(self, event):
        wizard = ExerciseWizard(self.dlg)
        self.exerciseInfo = wizard.GetExerciseInfo()
        if self.exerciseInfo != []:
            self.SetTitle(self.exerciseInfo[0])
            self.SetUtility(self.exerciseInfo[1])
            self.SetMechanics(self.exerciseInfo[2])
            self.SetForce(self.exerciseInfo[3])
            self.SetInstructions(self.exerciseInfo[4])
            self.SetMuscles(self.exerciseInfo[5])
            self.SetComments(self.exerciseInfo[6])
            if self.exerciseInfo[7] != '':
                self.SetImage(os.path.join(imagesDir, self.exerciseInfo[7]))
                
    def ShowModal(self):
        return self.dlg.ShowModal()

    def SetDialogTitle(self, title):
        self.dlg.SetTitle(title)

    def GetTitle(self):
        return self.titleBox.GetValue()

    def GetUtility(self):
        if self.utilityBox.GetSelection() == -1:
            return 0
        else:
            return self.utilityBox.GetSelection()

    def GetMechanics(self): 
        if self.mechanicsBox.GetSelection() == -1:
            return 0
        else:
            return self.mechanicsBox.GetSelection()
   
    def GetForce(self):
        if self.forceBox.GetSelection() == -1:
            return 0
        else:
            return self.forceBox.GetSelection()

    def GetInstructions(self):
        return self.instructionsText.GetValue()

    def GetMuscles(self):
        return self.musclesText.GetValue()

    def GetComments(self):
        return self.commentsText.GetValue()

    def GetImage(self):
        return self.exerciseInfo[7]

    def GetExerciseInfo(self):
        title = self.GetTitle()
        if title != '' and title[0] != ' ':
            return [self.GetTitle(), self.GetUtility(), self.GetMechanics(),
                    self.GetForce(), self.GetInstructions(), self.GetMuscles(),
                    self.GetComments(), self.GetImage()]
        else:
            return []

    def SetTitle(self, value):
        if self.exerciseInfo[0] == '':
            self.exerciseInfo[0] = value
        self.titleBox.SetValue(value)

    def SetUtility(self, value): 
        if self.exerciseInfo[1] == '':
            self.exerciseInfo[1] = value
        self.utilityBox.SetSelection(value)

    def SetMechanics(self, value):
        if self.exerciseInfo[2] == '':
            self.exerciseInfo[2] = value
        self.mechanicsBox.SetSelection(value)

    def SetForce(self, value):
        if self.exerciseInfo[3] == '':
            self.exerciseInfo[3] = value
        self.forceBox.SetSelection(value)

    def SetInstructions(self, value):
        if self.exerciseInfo[4] == '':
            self.exerciseInfo[4] = value
        self.instructionsText.SetValue(value)

    def SetMuscles(self, value):
        if self.exerciseInfo[5] == '':
            self.exerciseInfo[5] = value
        self.musclesText.SetValue(value)

    def SetComments(self, value):
        if self.exerciseInfo[6] == '':
            self.exerciseInfo[6] = value
        self.commentsText.SetValue(value)

    def SetImage(self, filename):
        if self.exerciseInfo[7] == '':
            self.exerciseInfo[7] = filename
        sizer = wx.BoxSizer(wx.VERTICAL)
        aniCtrl = GIFAnimationCtrl(self.imageBox, size=(160,120),
                                   filename=filename)
        aniCtrl.GetPlayer().UseBackgroundColour(True)
        aniCtrl.Play()
        sizer.Add(aniCtrl, 1, wx.EXPAND)
        self.imageBox.SetSizerAndFit(sizer)

    
class AddExerciseDlg(ExerciseDlg):
    """New exercise dialog box"""

    def __init__(self, parent, resource):
        ExerciseDlg.__init__(self, parent, resource)

        self.SetDialogTitle(_("Add new exercise"))


class EditExerciseDlg(ExerciseDlg):
    """Edit exercise dialog box"""

    def __init__(self, parent, resource, data):
        ExerciseDlg.__init__(self, parent, resource)

        self.SetDialogTitle(_("Edit exercise"))

        self.SetTitle(data[0])
        self.SetUtility(data[1])
        self.SetMechanics(data[2])
        self.SetForce(data[3])
        self.SetInstructions(data[4])
        self.SetMuscles(data[5])
        self.SetComments(data[6])
        self.SetImage(os.path.join(imagesDir, data[7]))
